# coding: utf-8

"""
    Managed Ray API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from openapi_client.configuration import Configuration


class AlertType(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    LOW_CREDIT_BALANCE_REACHED = "low_credit_balance_reached"
    SPEND_THRESHOLD_REACHED = "spend_threshold_reached"
    LOW_REMAINING_DAYS_IN_PLAN_REACHED = "low_remaining_days_in_plan_reached"
    LOW_REMAINING_CREDIT_PERCENTAGE_REACHED = "low_remaining_credit_percentage_reached"
    USAGE_THRESHOLD_REACHED = "usage_threshold_reached"
    LOW_REMAINING_COMMIT_BALANCE_REACHED = "low_remaining_commit_balance_reached"
    LOW_REMAINING_COMMIT_PERCENTAGE_REACHED = "low_remaining_commit_percentage_reached"
    LOW_REMAINING_DAYS_FOR_COMMIT_SEGMENT_REACHED = "low_remaining_days_for_commit_segment_reached"
    LOW_REMAINING_CONTRACT_CREDIT_BALANCE_REACHED = "low_remaining_contract_credit_balance_reached"
    LOW_REMAINING_CONTRACT_CREDIT_PERCENTAGE_REACHED = "low_remaining_contract_credit_percentage_reached"
    LOW_REMAINING_DAYS_FOR_CONTRACT_CREDIT_SEGMENT_REACHED = "low_remaining_days_for_contract_credit_segment_reached"
    LOW_REMAINING_CONTRACT_CREDIT_AND_COMMIT_BALANCE_REACHED = "low_remaining_contract_credit_and_commit_balance_reached"
    MONTHLY_INVOICE_TOTAL_SPEND_THRESHOLD_REACHED = "monthly_invoice_total_spend_threshold_reached"
    INVOICE_TOTAL_REACHED = "invoice_total_reached"

    allowable_values = [LOW_CREDIT_BALANCE_REACHED, SPEND_THRESHOLD_REACHED, LOW_REMAINING_DAYS_IN_PLAN_REACHED, LOW_REMAINING_CREDIT_PERCENTAGE_REACHED, USAGE_THRESHOLD_REACHED, LOW_REMAINING_COMMIT_BALANCE_REACHED, LOW_REMAINING_COMMIT_PERCENTAGE_REACHED, LOW_REMAINING_DAYS_FOR_COMMIT_SEGMENT_REACHED, LOW_REMAINING_CONTRACT_CREDIT_BALANCE_REACHED, LOW_REMAINING_CONTRACT_CREDIT_PERCENTAGE_REACHED, LOW_REMAINING_DAYS_FOR_CONTRACT_CREDIT_SEGMENT_REACHED, LOW_REMAINING_CONTRACT_CREDIT_AND_COMMIT_BALANCE_REACHED, MONTHLY_INVOICE_TOTAL_SPEND_THRESHOLD_REACHED, INVOICE_TOTAL_REACHED]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """AlertType - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlertType):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AlertType):
            return True

        return self.to_dict() != other.to_dict()
